
:orphan:

Illumina
========

Automatically generated index page for Illumina:

.. raw:: html

   <ul>

   </ul>
     <a href="bcl2fastq.html">
       <p style="margin-bottom: 5px"><b>Bcl2Fastq</b> <span style="margin-left: 10px; color: darkgray">bcl2fastq</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="bcl2fastq.html" style="margin-bottom: 10px">
       v<b>2.20.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="happy_validator.html">
       <p style="margin-bottom: 5px"><b>Hap.py validation</b> <span style="margin-left: 10px; color: darkgray">happy_validator</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="happy_validator.html" style="margin-bottom: 10px">
       v<b>0.3.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="manta.html">
       <p style="margin-bottom: 5px"><b>Manta</b> <span style="margin-left: 10px; color: darkgray">manta</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="manta.html" style="margin-bottom: 10px">
       v<b>1.5.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="manta_cram.html">
       <p style="margin-bottom: 5px"><b>Manta</b> <span style="margin-left: 10px; color: darkgray">manta_cram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="manta_cram.html" style="margin-bottom: 10px">
       v<b>1.5.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelka_germline.html">
       <p style="margin-bottom: 5px"><b>Strelka (Germline)</b> <span style="margin-left: 10px; color: darkgray">strelka_germline</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="strelka_germline.html" style="margin-bottom: 10px">
       v<b>2.9.10</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelka_somatic.html">
       <p style="margin-bottom: 5px"><b>Strelka (Somatic)</b> <span style="margin-left: 10px; color: darkgray">strelka_somatic</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="strelka_somatic.html" style="margin-bottom: 10px">
       v<b>2.9.10</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelka_somatic_cram.html">
       <p style="margin-bottom: 5px"><b>Strelka (Somatic)</b> <span style="margin-left: 10px; color: darkgray">strelka_somatic_cram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="strelka_somatic_cram.html" style="margin-bottom: 10px">
       v<b>2.9.10</b>
     </a></p>
     </a>
     <hr />
         

